summaryrefslogtreecommitdiffstats
path: root/src/build/tools/genIStep.pl
diff options
context:
space:
mode:
authorMark Wenning <wenning@us.ibm.com>2012-02-29 18:35:29 -0600
committerA. Patrick Williams III <iawillia@us.ibm.com>2012-03-13 16:34:38 -0500
commit52bf33a35217406cf5118802e1da0f831ea95e15 (patch)
tree776a8ab62f459e89f9668ef7c2509bb4a8da6327 /src/build/tools/genIStep.pl
parent034d5adf483e55a961719122261e15eb4d72227c (diff)
downloadtalos-hostboot-52bf33a35217406cf5118802e1da0f831ea95e15.tar.gz
talos-hostboot-52bf33a35217406cf5118802e1da0f831ea95e15.zip
Update mc_init framework
- branch mc_init Supports HWP's for mss_volt, mss_freq, mss_eff_config_sim Tested on Simics Change-Id: Ic1d4d9c110f83a0371fac8d8669a833da0dcbfd7 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/715 Tested-by: Jenkins Server Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/build/tools/genIStep.pl')
-rwxr-xr-xsrc/build/tools/genIStep.pl19
1 files changed, 12 insertions, 7 deletions
diff --git a/src/build/tools/genIStep.pl b/src/build/tools/genIStep.pl
index 2cfe2eb7d..0e7c97d7a 100755
--- a/src/build/tools/genIStep.pl
+++ b/src/build/tools/genIStep.pl
@@ -125,12 +125,17 @@
#
# Make up a new directory src/usr/hwpf/hwp/<@istepname>/<@substepname>
# Copy code for new HWP to src/usr/hwpf/hwp/<@istepname>/<@substepname>. using git.
-# For example, to set up for istep 11.7, proc_gen_framelock :
-# ## cutNpaste the fetch comand from Gerrit. See the webpage at
-# ## http://gfw160.austin.ibm.com:8080/gerrit/#change,597
-# git fetch ssh://wenning@gfw160.austin.ibm.com:29418/hwp_review_centaur refs/changes/97/597/3
+# - Go to the Gerrit page where the HWP is, and select the line to generate
+# a patch
+# - run this line and pipe it to a file.
+# - then run:
+ git apply --directory=src/usr/hwpf/hwp/@istepname/@substepname <file>
+#
+# Example: istep 12.2, mss_eff_config:
+# ## cutNpaste the patch comand from Gerrit and pipe to a file:
+# git fetch ssh://wenning@gfw160.austin.ibm.com:29418/hwp_review_centaur refs/changes/63/663/3 && git format-patch -1 --stdout FETCH_HEAD > mss_eff_config.patch
# ## then run the git command to put the code in the right directory:
-# git diff FETCH_HEAD FETCH_HEAD~1 -R | git apply --directory=src/usr/hwpf/hwp/dmi_training/proc_gen_framelock
+# git apply --directory=src/usr/hwpf/hwp/mc_init/mss_eff_config mss_eff_config.patch
#
# Add makefile support for the new HWP:
# - Scan src/usr/hwpf/hwp/@substepname/makefile for the line:
@@ -354,7 +359,7 @@ void call_\@substepname( void *io_pArgs )
// set up loops to go through all targets (if parallel, spin off a task)
// print call to hwp and dump physical path of the target(s)
- TRACFCOMP( ISTEPS_TRACE::ISTEPS_TRACE::g_trac_isteps_traces_trace,
+ TRACFCOMP( ISTEPS_TRACE::g_trac_isteps_trace,
\"===== \@substepname HWP(? ? ? )\",
?
?
@@ -377,7 +382,7 @@ void call_\@substepname( void *io_pArgs )
// process return code.
if ( l_fapirc== fapi::FAPI_RC_SUCCESS )
{
- TRACFCOMP( ISTEPS_TRACE::ISTEPS_TRACE::g_trac_isteps_traces_trace,
+ TRACFCOMP( ISTEPS_TRACE::g_trac_isteps_trace,
\"SUCCESS : \@substepname HWP(? ? ? )\" );
}
else
OpenPOWER on IntegriCloud